<?php

/**
 * Class NewTrustedShopsModuleCenterModuleController
 */
class NewTrustedShopsModuleCenterModuleController extends AbstractModuleCenterModuleController
{
    /**
     * @var string
     */
    protected $jsBaseUrl;

    /**
     * @var string
     */
    protected $stylesBaseUrl;

    /**
     * @var
     */
    protected $db;

    /**
     * @var array
     */
    protected $options = [
        'TRUSTEDSHOPS_ID',
    ];

    /**
     * @var array
     */
    protected $errors = [];

    /**
     *
     */
    protected function _init()
    {
        $this->db = StaticGXCoreLoader::getDatabaseQueryBuilder();
        $this->stylesBaseUrl = '../GXModules/TrustedShopsAktuell/TrustedShopsAktuell/Admin/Styles';
        $this->jsBaseUrl     = '../GXModules/TrustedShopsAktuell/TrustedShopsAktuell/Admin/JavaScript';
        $this->pageTitle     = $this->languageTextManager->get_text('new_trustedshops_title');
        $this->contentView->set_template_dir(DIR_FS_CATALOG . 'GXModules/TrustedShopsAktuell/TrustedShopsAktuell/Admin/Html/');
    }

    /**
     * @return AdminPageHttpControllerResponse|bool|RedirectHttpControllerResponse
     */
    public function actionDefault()
    {
        $pageTitle       = new NonEmptyStringType($this->pageTitle);
        $templateData    = MainFactory::create('KeyValueCollection',
            ['config' => $this->_readConfig(), 'errors' => $this->errors]);


        $template        = new ExistingFile(new NonEmptyStringType(DIR_FS_CATALOG
            . 'GXModules/TrustedShopsAktuell/TrustedShopsAktuell/Admin/Html/trustedshops_configuration.html'));

        $assetsArray = [
            MainFactory::create('Asset', $this->stylesBaseUrl . '/trustedshops_overview.css'),
            MainFactory::create('Asset', $this->jsBaseUrl . '/tsAjaxController.js'),
        ];

        if($_SESSION['trustedshops_locale'] === NULL) {
            $_SESSION['trustedshops_locale'] = 'de';
        }

        $assetCollection = MainFactory::create('AssetCollection', $assetsArray);

        $nav = [
            $this->languageTextManager->get_text('new_trustedshops_label_overview') => '',
        ];

        if(isset($_SESSION['trustedshops_locale']) and empty($_SESSION['trustedshops_locale']) === false) {
            $result = $this->db->query("SELECT * FROM `trustedshops_configuration` WHERE trustedshops_locale='" . $_SESSION['trustedshops_locale'] . "'")->result_array();

            if(isset($result[0]['trustedshops_id']) and empty($result[0]['trustedshops_id']) === false) {
                $nav = [
                    $this->languageTextManager->get_text('new_trustedshops_label_overview')         => '',
                    $this->languageTextManager->get_text('new_trustedshops_label_trustbadge')       => './admin.php?do=NewTrustedShopsTrustbadge',
                    $this->languageTextManager->get_text('new_trustedshops_label_shop_reviews')     => './admin.php?do=NewTrustedShopsShopReview',
                    $this->languageTextManager->get_text('new_trustedshops_label_product_reviews')  => './admin.php?do=NewTrustedShopsProductReview',
                ];
            }
        }

        $navCollection = new ContentNavigationCollection($nav);

        return MainFactory::create('AdminLayoutHttpControllerResponse',
            $pageTitle,
            $template,
            $templateData,
            $assetCollection,
            $navCollection);
    }

    /**
     * @return AdminPageHttpControllerResponse|bool|RedirectHttpControllerResponse
     */
    public function actionProcess()
    {
        if ($this->_getPostDataCollection()->keyExists('delete_config')) {
            return $this->_deleteConfig();
        }

        if ($this->_validate($this->_getPostDataCollection()->getArray())) {
            $this->_saveConfig($this->_getPostDataCollection()->getArray());

            $GLOBALS['messageStack']->add($this->languageTextManager->get_text('new_trustedshops_save_config_success'),
                'success');
        }

        return $this->actionDefault();
    }

    /**
     * @return AdminPageHttpControllerResponse|bool|RedirectHttpControllerResponse
     */
    protected function _deleteConfig()
    {
        return $this->actionDefault();
    }

    /**
     * @param array $postData
     *
     * @return bool
     */
    protected function _validate(array $postData)
    {
        return 0 === count($this->errors);
    }

    /**
     * @param array $postData
     */
    protected function _saveConfig(array $postData)
    {
        $trustedShopsId =  trim($postData['TRUSTEDSHOPS_ID']);
        $locale         =  trim($postData['TRUSTEDSHOPS_LANGUAGE']);

        if(isset($locale) and empty($locale) === false) {
            if($this->updateTrustedShopsId($trustedShopsId, $locale)) {
                $this->updateTrustBadgeCode($trustedShopsId, $locale);
                $this->updateShopReviewCode($trustedShopsId, $locale);
                $this->updateProductReviewCode($trustedShopsId, $locale);
                $this->updateProductReviewStarsCode($trustedShopsId, $locale);
            }
        }

        $config['TRUSTEDSHOPS_ID'] = $trustedShopsId;
    }

    /**
     * @return array
     */
    protected function _readConfig()
    {
        $config = [];

        foreach ($this->options as $key) {
            $config[$key] = gm_get_conf($key);
        }

        return $config;
    }

    /**
     * @param $trustedShopsId
     * @param $locale
     *
     * @return mixed
     */
    public function updateTrustedShopsId($trustedShopsId, $locale)
    {
        $result = $this->db->query("SELECT * FROM `trustedshops_configuration` WHERE trustedshops_locale='" . $locale . "'");

        if(empty($result->result_array())) {
            $result = $this->db->query("INSERT INTO `trustedshops_configuration` (trustedshops_locale, trustedshops_id) VALUES ('" . $locale . "', '" . $trustedShopsId . "')");
        } else {
            $result = $this->db->query("UPDATE `trustedshops_configuration` SET trustedshops_id='" . $trustedShopsId . "' WHERE trustedshops_locale='" . $locale . "'");
        }

        return $result;
    }

    /**
     * @param $trustedShopsId
     * @param $locale
     *
     * @return mixed
     */
    private function updateTrustBadgeCode($trustedShopsId, $locale)
    {
        $trustedshopsTrustbadgeCode = $this->db->query("SELECT trustbadge_code FROM `trustedshops_configuration` WHERE trustedshops_locale='" . $locale . "' AND trustedshops_id='" . $trustedShopsId . "'")->result_array();

        if(isset($trustedshopsTrustbadgeCode[0]['trustbadge_code']) === false or is_null($trustedshopsTrustbadgeCode[0]['trustbadge_code'])) {
            $trustedshopsTrustbadgeCode = '<script async
                data-desktop-y-offset="0"
                data-mobile-y-offset="0"
                data-desktop-disable-reviews="false"
                data-desktop-enable-custom="false"
                data-desktop-position="right"
                data-desktop-custom-width="156"
                data-desktop-enable-fadeout="false"
                data-disable-mobile="false"
                data-disable-trustbadge="false"
                data-mobile-custom-width="156"
                data-mobile-disable-reviews="false"
                data-mobile-enable-custom="false"
                data-mobile-position="right"
                data-mobile-enable-topbar="false"
                src="//widgets.trustedshops.com/js/XXXXXXXXX.js"></script>';
        } else {
            $trustedshopsTrustbadgeCode = htmlspecialchars_decode($trustedshopsTrustbadgeCode[0]['trustbadge_code']);
        }

        $trustedshopsTrustbadgeCode = preg_replace("/(src=\"(.*)\")/", 'src=\"//widgets.trustedshops.com/js/' .  $trustedShopsId . '.js\"', $trustedshopsTrustbadgeCode);

        $result = $this->db->query("UPDATE `trustedshops_configuration` SET trustbadge_code='" . htmlspecialchars($trustedshopsTrustbadgeCode) . "' WHERE trustedshops_locale='" . $locale . "' AND trustedshops_id='" . $trustedShopsId . "'");

        return $result;
    }

    /**
     * @param $trustedShopsId
     * @param $locale
     *
     * @return mixed
     */
    private function updateShopReviewCode($trustedShopsId, $locale)
    {
        $trustedshopsShopReviewCode = $this->db->query("SELECT shop_review_code FROM `trustedshops_configuration` WHERE trustedshops_locale='" . $locale . "' AND trustedshops_id='" . $trustedShopsId . "'")->result_array();

        if(isset($trustedshopsShopReviewCode[0]['shop_review_code']) === false or is_null($trustedshopsShopReviewCode[0]['shop_review_code'])) {
            $trustedshopsShopReviewCode = '<script type="text/javascript">
                (function() {
                    _tsRatingConfig = {
                        tsid: "%tsid%",
                        variant: "testimonial",
                        reviews: "5",
                        betterThan: "3.0",
                        backgroundColor: "#ffdc0f",
                        linkColor: "#000000",
                        quotationMarkColor: "#FFFFFF",
                        fontFamily: "Arial",
                        reviewMinLength: "10"
                    };
                    var scripts = document.getElementsByTagName("SCRIPT"),
                        me = scripts[scripts.length - 1];
                    var _ts = document.createElement("SCRIPT");
                    _ts.type = "text/javascript";
                    _ts.async = true;
                    _ts.src =
                        "//widgets.trustedshops.com/reviews/tsSticker/tsSticker.js";
                    me.parentNode.insertBefore(_ts, me);
                    _tsRatingConfig.script = _ts;
                })();
                </script>';
        } else {
            $trustedshopsShopReviewCode = htmlspecialchars_decode($trustedshopsShopReviewCode[0]['shop_review_code']);
        }

        $trustedshopsShopReviewCode = preg_replace("/(tsid: \"(.*)\")/", 'tsid: "' .  $trustedShopsId . '"', $trustedshopsShopReviewCode);

        $result = $this->db->query("UPDATE `trustedshops_configuration` SET shop_review_code='" . htmlspecialchars($trustedshopsShopReviewCode) . "' WHERE trustedshops_locale='" . $locale . "' AND trustedshops_id='" . $trustedShopsId . "'");

        return $result;
    }

    /**
     * @param $trustedShopsId
     * @param $locale
     *
     * @return mixed
     */
    private function updateProductReviewCode($trustedShopsId, $locale)
    {
        $trustedshopsProductReviewCode = $this->db->query("SELECT product_review_code FROM `trustedshops_configuration` WHERE trustedshops_locale='" . $locale . "' AND trustedshops_id='" . $trustedShopsId . "'")->result_array();

        if(isset($trustedshopsProductReviewCode[0]['product_review_code']) === false or is_null($trustedshopsProductReviewCode[0]['product_review_code'])) {
            $trustedshopsProductReviewCode = '<script type="text/javascript">
                (function() {
                    _tsProductReviewsConfig = {
                        tsid: "%tsid%",
                        sku: ["ART-123"],
                        variant: "productreviews",
                        element: "#trustedShopsProductReviews",
                        /* optional */
                        borderColor: "#0DBEDC",
                        backgroundColor: "#ffffff",
                        locale: "en_GB",
                        starColor: "#FFDC0F",
                        starSize: "15px",
                        commentBorderColor: "#dad9d5", 
                        commentHideArrow: "false",
                        ratingSummary : "false",
                        maxHeight: "1200px",
                        hideEmptySticker: "false",
                        filter: "false",
                        richSnippets: "on",
                        introtext: "What our customers say about us:"
                        };
                        var scripts = document.getElementsByTagName("SCRIPT"), me = scripts[scripts.length - 1];
                        var _ts = document.createElement("SCRIPT");
                        _ts.type = "text/javascript";
                        _ts.async = true;
                        _ts.charset = "utf-8";
                        _ts.src ="//widgets.trustedshops.com/reviews/tsSticker/tsProductSticker.js";
                        me.parentNode.insertBefore(_ts, me);
                        _tsProductReviewsConfig.script = _ts;
                })();
                </script>';
        } else {
            $trustedshopsProductReviewCode = htmlspecialchars_decode($trustedshopsProductReviewCode[0]['product_review_code']);
        }

        $trustedshopsProductReviewCode = preg_replace("/(tsid: \"(.*)\")/", 'tsid: "' .  $trustedShopsId . '"', $trustedshopsProductReviewCode);

        $result = $this->db->query("UPDATE `trustedshops_configuration` SET product_review_code='" . htmlspecialchars($trustedshopsProductReviewCode) . "' WHERE trustedshops_locale='" . $locale . "' AND trustedshops_id='" . $trustedShopsId . "'");

        return $result;
    }

    /**
     * @param $trustedShopsId
     * @param $locale
     *
     * @return mixed
     */
    private function updateProductReviewStarsCode($trustedShopsId, $locale)
    {
        $trustedshopsProductReviewStarsCode = $this->db->query("SELECT product_review_stars_code FROM `trustedshops_configuration` WHERE trustedshops_locale='" . $locale . "' AND trustedshops_id='" . $trustedShopsId . "'")->result_array();

        if(isset($trustedshopsProductReviewStarsCode[0]['product_review_stars_code']) === false or is_null($trustedshopsProductReviewStarsCode[0]['product_review_stars_code'])) {
            $trustedshopsProductReviewStarsCode = '<script type="text/javascript" src="//widgets.trustedshops.com/reviews/tsSticker/tsProductStickerSummary.js"></script>
                <script type="text/javascript">
                  var summaryBadge = new productStickerSummary();
                  summaryBadge.showSummary({
                      "tsid": "%tsid%",
                      "sku": ["ART-123"],
                      "element": "#trustedShopsProductReviewStars",
                      "starColor": "#FFDC0F",
                      "starSize": "14px",
                      "fontSize": "12px",
                      "showRating": "true",
                      "scrollToReviews": "false",
                      "enablePlaceholder": "false",
                  });
              </script>';
        } else {
            $trustedshopsProductReviewStarsCode = htmlspecialchars_decode($trustedshopsProductReviewStarsCode[0]['product_review_stars_code']);
        }

        $trustedshopsProductReviewStarsCode = preg_replace("/(\"tsid\": \"(.*)\")/", '"tsid": "' .  $trustedShopsId . '"', $trustedshopsProductReviewStarsCode);

        $result = $this->db->query("UPDATE `trustedshops_configuration` SET product_review_stars_code='" . htmlspecialchars($trustedshopsProductReviewStarsCode) . "' WHERE trustedshops_locale='" . $locale . "' AND trustedshops_id='" . $trustedShopsId . "'");

        return $result;
    }
}
