<?php

/**
 * Class NewTrustedShopsProductReviewController
 */
class NewTrustedShopsProductReviewController extends AbstractModuleCenterModuleController
{
    /**
     * @var string
     */
    protected $jsBaseUrl;

    /**
     * @var string
     */
    protected $stylesBaseUrl;

    /**
     * @var
     */
    protected $db;

    /**
     * @var array
     */
    protected $options = [
        'TRUSTEDSHOPS_COLLECT_PRODUCT_REVIEWS_ACTIVE',
        'TRUSTEDSHOPS_PRODUCT_REVIEW_ACTIVE',
        'TRUSTEDSHOPS_PRODUCT_REVIEW_CODE',
        'TRUSTEDSHOPS_PRODUCT_REVIEW_STARS_ACTIVE',
        'TRUSTEDSHOPS_PRODUCT_REVIEW_STARS_CODE'
    ];

    /**
     * @var array
     */
    protected $errors = [];

    /**
     * Init
     */
    protected function _init()
    {
        $this->db            = StaticGXCoreLoader::getDatabaseQueryBuilder();
        $this->jsBaseUrl     = '../GXModules/TrustedShopsAktuell/TrustedShopsAktuell/Admin/JavaScript';
        $this->stylesBaseUrl = '../GXModules/TrustedShopsAktuell/TrustedShopsAktuell/Admin/Styles';
        $this->pageTitle     = $this->languageTextManager->get_text('new_trustedshops_title');

        $this->contentView->set_template_dir(DIR_FS_CATALOG . 'GXModules/TrustedShopsAktuell/TrustedShopsAktuell/Admin/Html/');
    }

    /**
     * @return AdminPageHttpControllerResponse|bool|RedirectHttpControllerResponse
     */
    public function actionDefault()
    {
        $pageTitle       = new NonEmptyStringType($this->pageTitle);
        $templateData    = MainFactory::create('KeyValueCollection',
            ['config' => $this->_readConfig(), 'errors' => $this->errors]);
        $template        = new ExistingFile(new NonEmptyStringType(DIR_FS_CATALOG
            . 'GXModules/TrustedShopsAktuell/TrustedShopsAktuell/Admin/Html/product_reviews_configuration.html'));

        $assetsArray = [
            MainFactory::create('Asset', $this->stylesBaseUrl . '/trustedshops_overview.css'),
            MainFactory::create('Asset', $this->jsBaseUrl . '/tsAjaxController.js'),
            MainFactory::create('Asset', $this->jsBaseUrl . '/switcher.js'),
        ];

        $assetCollection = MainFactory::create('AssetCollection', $assetsArray);

        $nav = [
            $this->languageTextManager->get_text('new_trustedshops_label_overview')         => './admin.php?do=NewTrustedShopsModuleCenterModule',
            $this->languageTextManager->get_text('new_trustedshops_label_trustbadge')       => './admin.php?do=NewTrustedShopsTrustbadge',
            $this->languageTextManager->get_text('new_trustedshops_label_shop_reviews')     => './admin.php?do=NewTrustedShopsShopReview',
            $this->languageTextManager->get_text('new_trustedshops_label_product_reviews')  => '',
        ];

        $navCollection = new ContentNavigationCollection($nav);

        return MainFactory::create('AdminLayoutHttpControllerResponse',
            $pageTitle,
            $template,
            $templateData,
            $assetCollection,
            $navCollection);
    }

    /**
     * @return AdminPageHttpControllerResponse|bool|RedirectHttpControllerResponse
     */
    public function actionProcess()
    {
        if ($this->_getPostDataCollection()->keyExists('delete_config')) {
            return $this->_deleteConfig();
        }

        if ($this->_validate($this->_getPostDataCollection()->getArray())) {
            $this->_saveConfig($this->_getPostDataCollection()->getArray());
            $GLOBALS['messageStack']->add($this->languageTextManager->get_text('new_trustedshops_save_config_success'),
                'success');
        }

        return $this->actionDefault();
    }

    /**
     * @return AdminPageHttpControllerResponse|bool|RedirectHttpControllerResponse
     */
    protected function _deleteConfig()
    {
        return $this->actionDefault();
    }

    /**
     * @param array $postData
     *
     * @return bool
     */
    protected function _validate(array $postData)
    {
        return 0 === count($this->errors);
    }

    /**
     * @param array $postData
     */
    protected function _saveConfig(array $postData)
    {
        $postData["TRUSTEDSHOPS_PRODUCT_REVIEW_CODE"]       = htmlspecialchars($postData["TRUSTEDSHOPS_PRODUCT_REVIEW_CODE"], ENT_NOQUOTES);
        $postData["TRUSTEDSHOPS_PRODUCT_REVIEW_STARS_CODE"] = htmlspecialchars($postData["TRUSTEDSHOPS_PRODUCT_REVIEW_STARS_CODE"], ENT_NOQUOTES);

        $this->db->query("UPDATE `trustedshops_configuration` SET product_review_code='" . $postData["TRUSTEDSHOPS_PRODUCT_REVIEW_CODE"] . "', product_review_stars_code='" . $postData["TRUSTEDSHOPS_PRODUCT_REVIEW_STARS_CODE"] . "', product_review_active='" . $postData['TRUSTEDSHOPS_PRODUCT_REVIEW_ACTIVE'] . "', collect_product_reviews='" . $postData['TRUSTEDSHOPS_COLLECT_PRODUCT_REVIEWS_ACTIVE'] . "', product_review_stars_active='" . $postData['TRUSTEDSHOPS_PRODUCT_REVIEW_STARS_ACTIVE'] . "' WHERE trustedshops_locale='" . $_SESSION['trustedshops_locale'] . "'");
    }

    /**
     * @return array
     */
    protected function _readConfig()
    {
        $config = [];

        $locale = $_SESSION['trustedshops_locale'];
        $result = $this->db->query("SELECT collect_product_reviews, product_review_code, product_review_active, product_review_stars_code, product_review_stars_active FROM `trustedshops_configuration` WHERE trustedshops_locale='" . $locale ."'")->result_array();

        $collectProductReviewsActive   = $result[0]['collect_product_reviews'];
        $productReviewCode             = $result[0]['product_review_code'];
        $productReviewActive           = $result[0]['product_review_active'];
        $productReviewStarsCode        = $result[0]['product_review_stars_code'];
        $productReviewStarsActive      = $result[0]['product_review_stars_active'];

        $config['TRUSTEDSHOPS_COLLECT_PRODUCT_REVIEWS_ACTIVE']  = $collectProductReviewsActive;
        $config['TRUSTEDSHOPS_PRODUCT_REVIEW_ACTIVE']           = $productReviewActive;
        $config['TRUSTEDSHOPS_PRODUCT_REVIEW_STARS_ACTIVE']     = $productReviewStarsActive;

        // Produktbewertungen
        if (isset($productReviewCode) and empty($productReviewCode) === false) {
            $config["TRUSTEDSHOPS_PRODUCT_REVIEW_CODE"] = htmlspecialchars_decode($productReviewCode);
        } else {
            $config["TRUSTEDSHOPS_PRODUCT_REVIEW_CODE"] = '<script type="text/javascript">
                (function() {
                    _tsProductReviewsConfig = {
                        tsid: "%tsid%",
                        sku: ["ART-123"],
                        variant: "productreviews",
                        element: "#trustedShopsProductReviews",        
                        /* optional */
                        borderColor: "#0DBEDC",
                        backgroundColor: "#ffffff",
                        locale: "en_GB",
                        starColor: "#FFDC0F",
                        starSize: "15px",
                        commentBorderColor: "#dad9d5", 
                        commentHideArrow: "false",
                        ratingSummary : "false",
                        maxHeight: "1200px",
                        hideEmptySticker: "false",
                        filter: "false",
                        richSnippets: "on",
                        introtext: "What our customers say about us:"
                        };
                        var scripts = document.getElementsByTagName("SCRIPT"), me = scripts[scripts.length - 1];
                        var _ts = document.createElement("SCRIPT");
                        _ts.type = "text/javascript";
                        _ts.async = true;
                        _ts.charset = "utf-8";
                        _ts.src ="//widgets.trustedshops.com/reviews/tsSticker/tsProductSticker.js";
                        me.parentNode.insertBefore(_ts, me);
                        _tsProductReviewsConfig.script = _ts;
                })();
                </script>';

            $this->db->query("UPDATE `trustedshops_configuration` SET product_review_code='" . htmlspecialchars($config["TRUSTEDSHOPS_PRODUCT_REVIEW_CODE"]) . "' WHERE trustedshops_locale='" . $_SESSION['trustedshops_locale'] . "'");

        }

        // Bewertungssterne
        if (isset($productReviewStarsCode) and empty($productReviewStarsCode) === false) {
            $config["TRUSTEDSHOPS_PRODUCT_REVIEW_STARS_CODE"] = htmlspecialchars_decode($productReviewStarsCode);
        } else {
            $config["TRUSTEDSHOPS_PRODUCT_REVIEW_STARS_CODE"] = '<script type="text/javascript" src="//widgets.trustedshops.com/reviews/tsSticker/tsProductStickerSummary.js"></script>
                <script type="text/javascript">
                  var summaryBadge = new productStickerSummary();
                  summaryBadge.showSummary({
                      "tsid": "%tsid%",
                      "sku": ["ART-123"],
                      "element": "#trustedShopsProductReviewStars",
                      "starColor": "#FFDC0F",
                      "starSize": "14px",
                      "fontSize": "12px",
                      "showRating": "true",
                      "scrollToReviews": "false",
                      "enablePlaceholder": "false",
                  });
              </script>';

            $this->db->query("UPDATE `trustedshops_configuration` SET product_review_stars_code='" . htmlspecialchars($config["TRUSTEDSHOPS_PRODUCT_REVIEW_STARS_CODE"]) . "' WHERE trustedshops_locale='" . $_SESSION['trustedshops_locale'] . "'");
        }

        return $config;
    }
}
