<?php

/**
 * Class NewTrustedShopsShopReviewController
 */
class NewTrustedShopsShopReviewController extends AbstractModuleCenterModuleController
{
    /**
     * @var string
     */
    protected $jsBaseUrl;

    /**
     * @var string
     */
    protected $stylesBaseUrl;

    /**
     * @var
     */
    protected $db;

    /**
     * @var array
     */
    protected $options = [
        'TRUSTEDSHOPS_SHOP_REVIEW_ACTIVE',
        'TRUSTEDSHOPS_SHOP_REVIEW_CODE',
    ];

    /**
     * @var array
     */
    protected $errors = [];

    /**
     *
     */
    protected function _init()
    {
        $this->db = StaticGXCoreLoader::getDatabaseQueryBuilder();
        $this->stylesBaseUrl = '../GXModules/TrustedShopsAktuell/TrustedShopsAktuell/Admin/Styles';
        $this->jsBaseUrl     = '../GXModules/TrustedShopsAktuell/TrustedShopsAktuell/Admin/JavaScript';
        $this->pageTitle = $this->languageTextManager->get_text('new_trustedshops_title');
        $this->contentView->set_template_dir(DIR_FS_CATALOG . 'GXModules/TrustedShopsAktuell/TrustedShopsAktuell/Admin/Html/');
    }

    /**
     * @return AdminPageHttpControllerResponse|bool|RedirectHttpControllerResponse
     */
    public function actionDefault()
    {
        $pageTitle       = new NonEmptyStringType($this->pageTitle);
        $templateData    = MainFactory::create('KeyValueCollection',
            ['config' => $this->_readConfig(), 'errors' => $this->errors]);
        $template        = new ExistingFile(new NonEmptyStringType(DIR_FS_CATALOG
            . 'GXModules/TrustedShopsAktuell/TrustedShopsAktuell/Admin/Html/shop_reviews_configuration.html'));

        $assetsArray = [
            MainFactory::create('Asset', $this->stylesBaseUrl . '/trustedshops_overview.css'),
            MainFactory::create('Asset', $this->jsBaseUrl . '/tsAjaxController.js'),
        ];

        $assetCollection = MainFactory::create('AssetCollection', $assetsArray);

        $nav = [
            $this->languageTextManager->get_text('new_trustedshops_label_overview')         => './admin.php?do=NewTrustedShopsModuleCenterModule',
            $this->languageTextManager->get_text('new_trustedshops_label_trustbadge')       => './admin.php?do=NewTrustedShopsTrustbadge',
            $this->languageTextManager->get_text('new_trustedshops_label_shop_reviews')     => '',
            $this->languageTextManager->get_text('new_trustedshops_label_product_reviews')  => './admin.php?do=NewTrustedShopsProductReview',
        ];

        $navCollection = new ContentNavigationCollection($nav);

        return MainFactory::create('AdminLayoutHttpControllerResponse',
            $pageTitle,
            $template,
            $templateData,
            $assetCollection,
            $navCollection);
    }

    /**
     * @return AdminPageHttpControllerResponse|bool|RedirectHttpControllerResponse
     */
    public function actionProcess()
    {
        if ($this->_getPostDataCollection()->keyExists('delete_config')) {
            return $this->_deleteConfig();
        }

        if ($this->_validate($this->_getPostDataCollection()->getArray())) {
            $this->_saveConfig($this->_getPostDataCollection()->getArray());
            $GLOBALS['messageStack']->add($this->languageTextManager->get_text('new_trustedshops_save_config_success'),
                'success');
        }

        return $this->actionDefault();
    }

    /**
     * @return AdminPageHttpControllerResponse|bool|RedirectHttpControllerResponse
     */
    protected function _deleteConfig()
    {
        return $this->actionDefault();
    }

    /**
     * @param array $postData
     *
     * @return bool
     */
    protected function _validate(array $postData)
    {
        return 0 === count($this->errors);
    }

    /**
     * @param array $postData
     */
    protected function _saveConfig(array $postData)
    {
        $postData["TRUSTEDSHOPS_SHOP_REVIEW_CODE"] = htmlspecialchars($postData["TRUSTEDSHOPS_SHOP_REVIEW_CODE"], ENT_NOQUOTES);

        $this->db->query("UPDATE `trustedshops_configuration` SET shop_review_code='" . $postData["TRUSTEDSHOPS_SHOP_REVIEW_CODE"] . "', shop_review_active='" . $postData['TRUSTEDSHOPS_SHOP_REVIEW_ACTIVE'] . "' WHERE trustedshops_locale='" . $_SESSION['trustedshops_locale'] . "'");
    }

    /**
     * @return array
     */
    protected function _readConfig()
    {
        $config = [];

        $locale = $_SESSION['trustedshops_locale'];
        $result = $this->db->query("SELECT shop_review_code, shop_review_active FROM `trustedshops_configuration` WHERE trustedshops_locale='" . $locale ."'")->result_array();

        $shopReviewCode   = $result[0]['shop_review_code'];
        $shopReviewActive = $result[0]['shop_review_active'];

        $config["TRUSTEDSHOPS_SHOP_REVIEW_ACTIVE"] = $shopReviewActive;

        if (isset($shopReviewCode) and empty($shopReviewCode) === false) {
            $config["TRUSTEDSHOPS_SHOP_REVIEW_CODE"] = htmlspecialchars_decode($shopReviewCode);
        } else {
            $config["TRUSTEDSHOPS_SHOP_REVIEW_CODE"] = '<script type="text/javascript">
                (function() {
                    _tsRatingConfig = {
                        tsid: "%tsid%",
                        variant: "testimonial",
                        reviews: "5",
                        betterThan: "3.0",   
                        backgroundColor: "#ffdc0f",
                        linkColor: "#000000",
                        quotationMarkColor: "#FFFFFF",
                        fontFamily: "Arial",
                        reviewMinLength: "10"
                    };
                    var scripts = document.getElementsByTagName("SCRIPT"),
                        me = scripts[scripts.length - 1];
                    var _ts = document.createElement("SCRIPT");
                    _ts.type = "text/javascript";
                    _ts.async = true;
                    _ts.src =
                        "//widgets.trustedshops.com/reviews/tsSticker/tsSticker.js";
                    me.parentNode.insertBefore(_ts, me);
                    _tsRatingConfig.script = _ts;
                })();
                </script>';

            $shopReviewCode = htmlspecialchars($config["TRUSTEDSHOPS_SHOP_REVIEW_CODE"]);
            $this->db->query("UPDATE `trustedshops_configuration` SET shop_review_code='$shopReviewCode' WHERE trustedshops_locale='" . $_SESSION['trustedshops_locale'] . "'");
        }

        return $config;
    }
}
