<?php

/**
 * Class NewTrustedShopsThemeProductInfo
 */
class NewTrustedShopsThemeProductInfo extends NewTrustedShopsThemeProductInfo_parent
{
    /**
     * Prepare data
     */
    public function prepare_data()
    {
        $this->initNewTrustedShopsProductInfo();
        parent::prepare_data();
    }

    /**
     *
     */
    protected function initNewTrustedShopsProductInfo()
    {
        $db = StaticGXCoreLoader::getDatabaseQueryBuilder();

        $installed = (bool) gm_get_conf('MODULE_CENTER_NEWTRUSTEDSHOPS_INSTALLED');

        if ($installed === true) {
            $result = $db->select('trustedshops_id')->from('trustedshops_configuration')->where('trustedshops_locale', $_SESSION['language_code'])->get()->row_array();

            if(isset($result['trustedshops_id']) and empty($result['trustedshops_id']) === false) {
                $sku = $this->getSkuTrustedShops();

                $languageCode = $_SESSION['language_code'];

                switch($languageCode) {
                    case "de":
                        $productReviewsLabel = "Trusted Shops Bewertungen";
                        break;

                    case "en":
                        $productReviewsLabel = "Trusted Shops Reviews";
                        break;

                    default:
                        $productReviewsLabel = "Trusted Shops Bewertungen";
                        break;
                }

                $trustedshopsCollectProductReviewsActive    = $db->select('collect_product_reviews')->from('trustedshops_configuration')->where('trustedshops_locale', $languageCode)->get()->row_array();
                $trustedshopsProductReviewCodeActive        = $db->select('product_review_active')->from('trustedshops_configuration')->where('trustedshops_locale', $languageCode)->get()->row_array();
                $trustedshopsProductReviewCode              = $db->select('product_review_code')->from('trustedshops_configuration')->where('trustedshops_locale', $languageCode)->get()->row_array();
                $trustedshopsProductReviewStarsCode         = $db->select('product_review_stars_code')->from('trustedshops_configuration')->where('trustedshops_locale', $languageCode)->get()->row_array();
                $trustedshopsProductReviewStarsActive       = $db->select('product_review_stars_active')->from('trustedshops_configuration')->where('trustedshops_locale', $languageCode)->get()->row_array();

                $trustedshopsProductReviewCode = htmlspecialchars_decode($trustedshopsProductReviewCode["product_review_code"]);
                $trustedshopsProductReviewCode = preg_replace("/(sku: \[\"(.*)\"\])/", 'sku: ' . "['" .  $sku . "']", $trustedshopsProductReviewCode);
                $trustedshopsProductReviewCode = preg_replace("/(locale: \"(.*)\")/", 'locale: ' . '"' .  $this->getLocaleTrustedShops() . '"', $trustedshopsProductReviewCode);

                $trustedshopsProductReviewStarsCode = htmlspecialchars_decode($trustedshopsProductReviewStarsCode["product_review_stars_code"]);
                $trustedshopsProductReviewStarsCode = preg_replace("/(\"sku\": \[\"(.*)\"\])/", 'sku: ' . "['" .  $sku . "']", $trustedshopsProductReviewStarsCode);

                preg_match("/(\"fontSize\": \"(.*)\")/", $trustedshopsProductReviewStarsCode, $tsFontSize);
                preg_match("/(\"starSize\": \"(.*)\")/", $trustedshopsProductReviewStarsCode, $tsStarSize);

                $tsFontSize = json_decode("{" . $tsFontSize[0] . "}");
                $tsFontSize = str_replace("px", "", $tsFontSize->fontSize);

                $tsStarSize = json_decode("{" . $tsStarSize[0] . "}");
                $tsStarSize = str_replace("px", "", $tsStarSize->starSize);

                $this->content_array['trustedshops_collect_product_reviews_active'] = $trustedshopsCollectProductReviewsActive['collect_product_reviews'];
                $this->content_array['trustedshops_product_review_active']          = $trustedshopsProductReviewCodeActive['product_review_active'];
                $this->content_array['trustedshops_product_review_stars_active']    = $trustedshopsProductReviewStarsActive['product_review_stars_active'];
                $this->content_array['trustedshops_product_review_code']            = $trustedshopsProductReviewCode;
                $this->content_array['trustedshops_product_review_stars_code']      = $trustedshopsProductReviewStarsCode;
                $this->content_array['trustedshops_product_review_label']           = $productReviewsLabel;
                $this->content_array['trustedshops_font_size']                      = $tsFontSize;
                $this->content_array['trustedshops_star_size']                      = $tsStarSize;
            }
        }
    }

    /**
     * @return mixed
     */
    private function getSkuTrustedShops()
    {
        $sku = $this->product->pID;

        if(!empty($this->product->data['products_model']))
        {
            $sku = $this->product->data['products_model'];
        }
        else if(!empty($this->product->data['products_ean']))
        {
            $sku = $this->product->data['products_ean'];
        }

        return $sku;
    }

    /**
     * @return string
     */
    private function getLocaleTrustedShops()
    {
        switch($_SESSION['language_code'])
        {
            case 'en':
                $locale = 'en_GB';
                break;
            case 'es':
                $locale = 'es_ES';
                break;
            case 'fr':
                $locale = 'fr_FR';
                break;
            case 'pl':
                $locale = 'pl_PL';
                break;
            default:
                $locale = 'de_DE';
        }
        return $locale;
    }
}
